# Condition Objects 

You can find [an introduction to Conditions](https://pdpipe.readthedocs.io/en/latest/starting/cond/) in our Getting Started section.

[An Introduction to Conditions :fontawesome-solid-leanpub:](https://pdpipe.readthedocs.io/en/latest/starting/cond/){ .md-button .md-button--primary}

::: pdpipe.cond
